mathtools.all_are_positive_integer_equivalent_numbers
=====================================================

.. autofunction:: abjad.tools.mathtools.all_are_positive_integer_equivalent_numbers.all_are_positive_integer_equivalent_numbers
